@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use vars qw($VERSION);
 
-$VERSION = '0.02';
+$VERSION = '0.03';
 
 
 # Constructor. Enables Inheritance
@@ -27,17 +27,17 @@ sub new {
 # Duplicates are not allowed - might be optional if needed in the future
 sub insert {
 	# Arguments check
-	return 'List::Priority - Expected 3 arguements!' if (scalar(@_) != 3);
-	
+	return 'List::Priority - Expected 3 arguments!' if (scalar(@_) != 3);
+
 	# Argument assignment
 	my $self = shift;
 	my $priority = shift;
 	my $object = shift;
-	
+
 	# Check that priority is numeric - Thanks Randel/Joseph!
-	return 'List::Priority - Priority must be numeric!' 
+	return 'List::Priority - Priority must be numeric!'
 		if ((~$priority & $priority) ne '0');
-	
+
 	# Check that the object isn't already in the list
 	if (defined($self->{queues}{$priority})) {
 	    foreach (@{$self->{queues}{$priority}}) {
@@ -48,10 +48,10 @@ sub insert {
 
 	# If the list is full
 	if (exists($self->{options}{SIZE}) and
-		$self->{options}{SIZE} <= $self->{size}) 
+		$self->{options}{SIZE} <= $self->{size})
 	{
 		my ($bottom_priority) = (sort {$a <=> $b} keys %{$self->{queues}});
-		# And the object's priority is higher then the lowest on on the list 
+		# And the object's priority is higher than the lowest on on the list
 		# - remove the lowest one to insert it
 		if ($priority > $bottom_priority) {
 			$self->shift($bottom_priority);
@@ -62,7 +62,7 @@ sub insert {
 		}
 	}
 
-	
+
 	# Insert
 	push(@{$self->{queues}{$priority}}, $object);
 	++$self->{size};
@@ -71,12 +71,12 @@ sub insert {
 
 sub pop {
 	# Arguments check
-	return 'List::Priority - Pop expected 1 or 2 arguements!' 
+	return 'List::Priority - Pop expected 1 or 2 arguments!'
 		if (scalar(@_) != 1 and scalar(@_) != 2);
 
 	my ($self, $top_priority) = @_;
 	return undef if ($self->{size} == 0);
-	
+
 	if (defined($top_priority)) {
 		return undef unless (defined($self->{queues}{$top_priority}));
 	}
@@ -88,11 +88,11 @@ sub pop {
 
 	# Remove the queue's first element
 	my $object = shift (@{$self->{queues}{$top_priority}});
-	
+
 	# If the queue is now empty - delete it
-	delete $self->{queues}{$top_priority} 
-		if (scalar(@{$self->{queues}{$top_priority}}) == 0); 
-	
+	delete $self->{queues}{$top_priority}
+		if (scalar(@{$self->{queues}{$top_priority}}) == 0);
+
 	# Return the object I just shifted out of the queue
 	--$self->{size};
 	return $object;
@@ -100,33 +100,38 @@ sub pop {
 
 sub shift {
 	# Arguments check
-	return 'List::Priority - Unshift expected 1 or 2 arguements!' 
+	return 'List::Priority - Unshift expected 1 or 2 arguments!'
 		if (scalar(@_) != 1 and scalar(@_) != 2);
 
 	my ($self, $bottom_priority) = @_;
 	return undef if ($self->{size} == 0);
-	
+
 	if (defined($bottom_priority)) {
 		return undef unless (defined($self->{queues}{$bottom_priority}));
 	}
 	else {
 		# Find out the bottom priority
-		($bottom_priority) = (sort {$b <=> $a} keys %{$self->{queues}});
+		($bottom_priority) = (sort {$a <=> $b} keys %{$self->{queues}});
 		return undef unless (defined ($bottom_priority));
 	}
 
 	# Remove the queue's last element
 	my $object = CORE::pop (@{$self->{queues}{$bottom_priority}});
-	
+
 	# If the queue is now empty - delete it
-	delete $self->{queues}{$bottom_priority} 
-		if (scalar(@{$self->{queues}{$bottom_priority}}) == 0); 
-	
+	delete $self->{queues}{$bottom_priority}
+		if (scalar(@{$self->{queues}{$bottom_priority}}) == 0);
+
 	# Return the object I just shifted out of the queue
 	--$self->{size};
 	return $object;
 }
 
+sub size {
+	my ($self) = @_;
+	return $self->{size};
+}
+
 1;
 __END__
 # Documentation
@@ -139,16 +144,17 @@ List::Priority - Perl extension for a list that manipulates objects by their pri
 =head1 SYNOPSIS
 
   use List::Priority;
-  
+
   # Create an instance
   my $list = List::Priority->new();
-  
-  # Insert some elements, each woth a unique priority
+
+  # Insert some elements, each with a unique priority
   $list->insert(2,'World!');
   $list->insert(5,'Hello');
   $list->insert(3,' ');
-  
+
   # Print
+  print $list->size()			# prints 3
   while (my $element = $list->pop()) {
   	  print $element;
   }
@@ -156,92 +162,95 @@ List::Priority - Perl extension for a list that manipulates objects by their pri
 
 =head1 DESCRIPTION
 
-If you want to handle multiple data bits by their order of importance -
-This one's for you.
+If you want to handle multiple data items by their order of importance,
+this one's for you.
 
-Logic:
-Precedence to highest priority object.
-If more than one object hold the highest priority - FIFO is king.
+You may retrieve the highest-priority item from the list using C<pop()>, or the
+lowest-priority item from the list using C<shift()>. If two items have the same
+priority, they are returned in first-in, first-out order. New items are
+inserted using C<insert()>.
 
-Duplicate objects are currently not allowed.
+You can constrain the capacity of the list using the C<SIZE> parameter at
+construction time. Low-priority items are automatically evicted once the
+specified capacity is exceeded. By default the list's capacity is unlimited.
+
+It is currently not allowed to insert the same object (determined by C<eq>)
+twice with the same priority.
 
 I'd like to thank Joseph N. Hall and Randal L. Schwartz for their
-excellent book "Effective Perl Programming" for one of the code hacks...
-
+excellent book "Effective Perl Programming" for one of the code hacks.
 
 =head1 METHODS
 
 =over 4
 
 
-=item B<new> - Constructor
+=item B<new>
 
   $p_list = List::Priority->new();
-	  
-B<new> is the constructor for List::Priority objects
 
-Arguments:
+B<new> is the constructor for List::Priority objects. It accepts a key-value
+list with the list attributes.
 
-- Accepts an Key-Value list with the list attributes.
+=over 
 
-  Key: SIZE - The maximum size of the list.
-              Inserting after the size is reached will result 
-              either in a no-op, or the removal of the most recent 
-              lowest priority objects - according to the insert()'s 
-              priority.
+=item * B<SIZE>
 
-              Example : $list = List::Priority->new(SIZE => 10);
+The maximum size of the list.
 
-=item B<insert> - List insertion
+Inserting after the size is reached will result
+either in a no-op, or the removal of the most recent
+lowest priority objects, according to the C<insert()>'s
+priority.
+
+  $list = List::Priority->new(SIZE => 10);
+
+=back
+
+=item B<insert>
 
   $result = $p_list->insert($priority, $scalar);
-	  
-Inserts the scalar to the list
 
-Arguments:
+Inserts the scalar to the list.
 
- 1. Priority must be numeric.
- 2. Scalar can be any scalar, including references (objects)
+C<$priority> must be numeric.
 
-Return value:
+C<$scalar> can be any scalar, including references (objects).
 
-1 on success, a string describing the error upon failure
+Returns 1 on success, and a string describing the error upon failure.
 
-=item B<pop> - List extraction
+=item B<pop>
 
   $object = $p_list->pop();
-	  
-Extracts the scalar from the list according to the specified logic.
 
-Arguments:
+Extracts the highest-priority scalar from the list.
+As an optional argument, takes the specific priority value to pop from, instead
+of the most important one.
 
-- Optional - The specific priority value to pop from, 
-             instead of the most important one.
+  $best_object_p3 = $list->pop(3);
 
-             Example : $best_object_p3 = $list->pop(3);
+Returns the object on success, C<undef> upon failure.
 
-Return value:
-
-The object on success, undef upon failure
-
-=item B<shift> - Reversed list extraction
+=item B<shift>
 
   $object = $p_list->shift();
-	  
-Extracts the scalar from the list according to the B<reversed> specified logic (least worthy first).
 
-Arguments:
+Extracts the B<lowest>-priority scalar from the list.
 
-- Optional 
-           - The specific priority value to shift from,
-             instead of the least important one.
- 
-             Example : $worst_object_p3 = $list->shift(3);
+As an optional argument, takes the specific priority value to shift from,
+instead of the least important one.
 
-Return value:
+  $worst_object_p3 = $list->shift(3);
 
-The object on success, undef upon failure
+Returns the object on success, C<undef> upon failure.
 
+=item B<size>
+
+  $num_elts = $p_list->size();
+
+Takes no arguments. Returns the number of elements in the priority queue.
+
+=back
 
 =head1 EXPORT
 
@@ -250,16 +259,24 @@ None. All interfaces are OO.
 
 =head1 TODO
 
-Well, I'm dangerously neglecting the testing bit...
+More tests.
 
 
 =head1 AUTHOR
 
 Eyal Udassin, <eyaludassin@hotmail.com>
 
+Currently maintained by Miles Gould, <miles@assyrian.org.uk>
+
+Thanks to Maik Hentsche for bugfixes.
+
+=head1 CONTRIBUTING
+
+You can find the Git repository at L<http://github.com/pozorvlak/List-Priority>.
 
 =head1 SEE ALSO
 
-L<Set::Scalar>.
+L<Heap::Priority>, L<List::PriorityQueue>, L<Hash::PriorityQueue>,
+L<POE::Queue>, L<Timeout::Queue>, L<Data::PrioQ::SkewBinomial>.
 
 =cut
